@@ -25,80 +25,74 @@ class DescribeVulListRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'DescribeVulList')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_AttachTypes(self):
+	def get_AttachTypes(self): # String
 		return self.get_query_params().get('AttachTypes')
 
-	def set_AttachTypes(self,AttachTypes):
-		self.add_query_param('AttachTypes',AttachTypes)
-
-	def get_Type(self):
+	def set_AttachTypes(self, AttachTypes):  # String
+		self.add_query_param('AttachTypes', AttachTypes)
+	def get_Type(self): # String
 		return self.get_query_params().get('Type')
 
-	def set_Type(self,Type):
-		self.add_query_param('Type',Type)
-
-	def get_VpcInstanceIds(self):
+	def set_Type(self, Type):  # String
+		self.add_query_param('Type', Type)
+	def get_VpcInstanceIds(self): # String
 		return self.get_query_params().get('VpcInstanceIds')
 
-	def set_VpcInstanceIds(self,VpcInstanceIds):
-		self.add_query_param('VpcInstanceIds',VpcInstanceIds)
-
-	def get_GroupId(self):
+	def set_VpcInstanceIds(self, VpcInstanceIds):  # String
+		self.add_query_param('VpcInstanceIds', VpcInstanceIds)
+	def get_GroupId(self): # String
 		return self.get_query_params().get('GroupId')
 
-	def set_GroupId(self,GroupId):
-		self.add_query_param('GroupId',GroupId)
-
-	def get_AliasName(self):
+	def set_GroupId(self, GroupId):  # String
+		self.add_query_param('GroupId', GroupId)
+	def get_AliasName(self): # String
 		return self.get_query_params().get('AliasName')
 
-	def set_AliasName(self,AliasName):
-		self.add_query_param('AliasName',AliasName)
+	def set_AliasName(self, AliasName):  # String
+		self.add_query_param('AliasName', AliasName)
+	def get_Name(self): # String
+		return self.get_query_params().get('Name')
 
-	def get_Necessity(self):
+	def set_Name(self, Name):  # String
+		self.add_query_param('Name', Name)
+	def get_Necessity(self): # String
 		return self.get_query_params().get('Necessity')
 
-	def set_Necessity(self,Necessity):
-		self.add_query_param('Necessity',Necessity)
-
-	def get_Uuids(self):
+	def set_Necessity(self, Necessity):  # String
+		self.add_query_param('Necessity', Necessity)
+	def get_Uuids(self): # String
 		return self.get_query_params().get('Uuids')
 
-	def set_Uuids(self,Uuids):
-		self.add_query_param('Uuids',Uuids)
-
-	def get_Remark(self):
+	def set_Uuids(self, Uuids):  # String
+		self.add_query_param('Uuids', Uuids)
+	def get_Remark(self): # String
 		return self.get_query_params().get('Remark')
 
-	def set_Remark(self,Remark):
-		self.add_query_param('Remark',Remark)
-
-	def get_PageSize(self):
+	def set_Remark(self, Remark):  # String
+		self.add_query_param('Remark', Remark)
+	def get_PageSize(self): # Integer
 		return self.get_query_params().get('PageSize')
 
-	def set_PageSize(self,PageSize):
-		self.add_query_param('PageSize',PageSize)
-
-	def get_Lang(self):
+	def set_PageSize(self, PageSize):  # Integer
+		self.add_query_param('PageSize', PageSize)
+	def get_Lang(self): # String
 		return self.get_query_params().get('Lang')
 
-	def set_Lang(self,Lang):
-		self.add_query_param('Lang',Lang)
-
-	def get_Dealed(self):
+	def set_Lang(self, Lang):  # String
+		self.add_query_param('Lang', Lang)
+	def get_Dealed(self): # String
 		return self.get_query_params().get('Dealed')
 
-	def set_Dealed(self,Dealed):
-		self.add_query_param('Dealed',Dealed)
-
-	def get_CurrentPage(self):
+	def set_Dealed(self, Dealed):  # String
+		self.add_query_param('Dealed', Dealed)
+	def get_CurrentPage(self): # Integer
 		return self.get_query_params().get('CurrentPage')
 
-	def set_CurrentPage(self,CurrentPage):
-		self.add_query_param('CurrentPage',CurrentPage)
\ No newline at end of file
+	def set_CurrentPage(self, CurrentPage):  # Integer
+		self.add_query_param('CurrentPage', CurrentPage)
